<?php

namespace Drupal\component_schema\Component\Schema;

use Drupal\component_schema\Component\Schema\TypedComponentVariableInterface;
use Drupal\Core\Template\Attribute;

trait ComponentVariableArrayElementTrait {

  /**
   * Helper method to initialize array-type values.
   *
   * @param array|null $value
   *   An array of property values.
   */
  protected function doInitializeValue(&$value) {
    if (isset($value) && !is_array($value)) {
      throw new \InvalidArgumentException("Invalid values given. Values must be represented as an associative array.");
    }

    $elements = $this->getElements();

    // First seed attributes, as the other element types may reference them.
    foreach ($elements as $name => $element) {
      if ($element instanceOf ComponentAttribute) {
        $element_value = $value[$name] ?? NULL;
        $element->initializeValue($element_value);
        $value[$name] = $element_value;
      }
    }

    // Iterate through non-attribute echild elements.
    foreach ($elements as $name => $element) {
      // We've covered the attributes elements above.
      if ($element instanceOf ComponentAttribute) {
        continue;
      }
      $element_value = $value[$name] ?? NULL;

      // ::initializeValue() is a method of TypedComponentVariableInterface.
      if ($element instanceOf TypedComponentVariableInterface) {
        $element->initializeValue($element_value);
      }

      $value[$name] = $element_value;
    }
  }

}
